from dataclass_factory import Schema
from dataclasses import dataclass

from typing import Union


class URL:
    new_install = 'https://ashyq.curs.kz/ashyq/v2/api/otp/newInstall'
    connect = 'https://ashyq.curs.kz/ashyq/identity/connect/token'
    user = 'https://ashyq.curs.kz/ashyq/v2/api/user'
    qrpass = 'https://ashyq.curs.kz/ashyq/v2/api/qrpass/check'
    employee_check = 'https://ashyq.curs.kz/ashyq/v2/api/qrpass/employee/check'


@dataclass
class Code(Schema):
    code: None


@dataclass
class Connect(Schema):
    access_token: str
    refresh_token: str
    expires_in: int
    token_type: str


@dataclass
class User(Schema):
    id: str
    iin: str
    entry_scanner: bool
    apartment: Union[str, None]
    building: Union[str, None]
    home_phone_number: Union[str, None]
    house: Union[str, None]
    first_name: Union[str, None]
    last_name: Union[str, None]
    email: Union[str, None]
    mobile_phone_number: Union[str, None]
    patronymic_name: Union[str, None]
    photo_url: Union[str, None]
    street: Union[str, None]


@dataclass
class Check(Schema):
    bin: str
    iin: str
    code: str
    building_rka: str
    name: str
    date: str
    indicator: str
    status: str
    status_id: int
    status_description: str
    message: str
    type: str
    _pass: bool



import pathlib
import re
import sys

from setuptools import find_packages, setup


WORK_DIR = pathlib.Path(__file__).parent

MINIMAL_PY_VERSION = (3, 5)

if sys.version_info < MINIMAL_PY_VERSION:
    raise RuntimeError('ashyq works only with Python {}+'.format('.'.join(map(str, MINIMAL_PY_VERSION))))


def get_version():
    txt = (WORK_DIR / 'ashyq' / '__init__.py').read_text('utf-8')

    try:
        return re.findall(r"^__version__ = '([^']+)'\r?$", txt, re.M)[0]
    except IndexError:
        raise RuntimeError('Unable to determine version.')


def get_description():
    with open('README.rst', 'r', encoding='utf-8') as f:
        return f.read()


setup(
    name='ashyq',
    version=get_version(),
    packages=find_packages(exclude=('examples.*',)),
    url='https://github.com/arynyklas/ashyq',
    license='MIT',
    author='Aryn Yklas',
    requires_python='>=3.5',
    author_email='arynyklas@gmail.com',
    description='Is a simple and synchronous framework for Private Ashyq API',
    long_description=get_description(),
    classifiers=[
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
		'License :: OSI Approved :: MIT License',
		'Operating System :: OS Independent',
    ],
    install_requires=[
        'requests>=2.26.0',
        'aiohttp>=3.7.4',
        'dataclass-factory>=2.11'
    ],
    include_package_data=False,
)
